@@ -14,6 +14,10 @@ from typing import Any, Dict
 
 from sphinx.application import Sphinx
 
+from .admonitions_ids import AdmonitionId
+from .html_translator import BetterHTMLTranslator
+from .postprocess import post_process_html
+
 try:
     __version__ = version(__name__)
 except PackageNotFoundError:  # pragma: no cover
@@ -24,6 +28,10 @@ def setup(app: "Sphinx") -> Dict[str, Any]:
     """Register the theme."""
     app.add_html_theme("sphinxawesome_theme", path.abspath(path.dirname(__file__)))
     app.setup_extension("sphinxawesome.sampdirective")
+    app.set_translator("html", BetterHTMLTranslator)
+    app.set_translator("dirhtml", BetterHTMLTranslator)
+    app.add_post_transform(AdmonitionId)
+    app.connect("build-finished", post_process_html)
 
     return {
         "version": __version__,
