@@ -26,9 +26,12 @@ def _get_html_files(outdir: str) -> List[str]:
     """Get a list of HTML files."""
     html_list = []
     for root, _dirs, files in os.walk(outdir):
-        for file in files:
-            if file.endswith(".html"):
-                html_list.append(os.path.join(root, file))
+        html_list.extend(
+            [os.path.join(root, file) for file in files if file.endswith(".html")]
+        )
+        #  for file in files:
+        #  if file.endswith(".html"):
+        #  html_list.append(os.path.join(root, file))
     return html_list
 
 
@@ -95,6 +98,37 @@ def _divs_to_section(tree: BeautifulSoup) -> None:
         del div["class"]
 
 
+def _add_focus_to_headings(tree: BeautifulSoup) -> None:
+    """Transform headlines so that they can receive focus.
+
+    Sphinx has a default structure of:
+    <h1>Title<a class="headerlink" href="...">#</a></h1>
+
+    What I want is:
+    <h1><a href="...">Title</a><a class="headerlink" href="...">#</a></h1>
+
+    This allows the headings to receive focus with the TAB key, as well as
+    allow logic to be applied on the headerlink '#' (click to copy).
+    Keyboard users can just use Ctrl+C on the focussed heading to achieve
+    the same goal.
+    """
+    for heading in tree.select(
+        "main h1, main h2, main h3, main h4, main h5, main h6, .admonition-title,"
+        "figcaption,.code-block-caption, table caption"
+    ):
+        headerlink = heading.find("a", class_="headerlink")
+        # make headerlinks (#) unfocussable
+        headerlink["tabindex"] = "-1"
+        caption_text = heading.find("span", class_="caption-text")
+        new_tag = tree.new_tag("a", href=headerlink["href"])
+        # figures, tables, code blocks
+        if caption_text:
+            caption_text.wrap(new_tag)
+        # h1-h6, admonitions
+        else:
+            heading.contents[0].wrap(new_tag)
+
+
 def _divs_to_figure(tree: BeautifulSoup) -> None:
     """Convert ``div.figure`` to semantic ``figure`` elements.
 
@@ -103,24 +137,21 @@ def _divs_to_figure(tree: BeautifulSoup) -> None:
     for div in tree("div", class_="figure"):
         div.name = "figure"
         div["class"].remove("figure")
-        caption = div("p", class_="caption")[0]
-        caption.name = "figcaption"
-        del caption["class"]
+        caption = div.find("p", class_="caption")
+        if caption:
+            caption.name = "figcaption"
+            del caption["class"]
 
 
 def _expand_current(tree: BeautifulSoup) -> None:
     """Add the ``.expanded`` class to li.current elements."""
     for li in tree("li", class_="current"):
         li["class"] += ["expanded"]
-        for sub in li("li", class_="toctree-l2"):
-            sub["class"] += ["expanded"]
 
 
 def _remove_pre_spans(tree: BeautifulSoup) -> None:
-    """Remove unnecessary nested ``span.pre`` elements in ``code."""
+    """Remove unnecessarily nested ``span.pre`` elements in inline ``code``."""
     for code in tree("code"):
-        # we don't need classes for inline code elements
-        del code["class"]
         for span in code("span", class_="pre"):
             span.unwrap()
 
@@ -141,6 +172,7 @@ def _modify_html(html_filename: str) -> None:
     _collapsible_nav(tree)
     _wrap_literal_blocks(tree)
     _add_copy_button(tree)
+    _add_focus_to_headings(tree)
     _remove_pre_spans(tree)
 
     with open(html_filename, "w") as out_file:
